@@ -34,7 +34,7 @@
 #' @param data is an n X 2 dataframe or matrix. First column defines X
 #'   (intially for horzontal axis), the second defines Y.
 #' @param main optional main title (as character); can be supplied by user. The default value is
-#'   \code{"default_granova_title"}, which leads to printing of a generic title for graphic.
+#'   \code{"default_granova_title"}, which will print a generic title for the graphic.
 #' @param revc reverses X,Y specifications
 #' @param xlab optional label (as character) for horizontal axis. If not
 #'   defined, axis labels are taken from colnames of data.
@@ -44,6 +44,12 @@
 #'   Defaults to \code{0.95} (95\% Confidence)
 #' @param plot.theme argument indicating a ggplot2 theme to apply to the
 #'   graphic; defaults to a customized theme created for the dependent sample graphic
+#' @param northeast.padding (numeric) extends axes toward lower left, 
+#'   effectively moving data points to the southwest. Defaults to zero padding.
+#' @param southwest.padding (numeric) extends axes toward upper right,
+#'   effectively moving data points to the southwest. Defaults to zero padding.
+#'   Making both southwest and northeast padding smaller moves points farther apart, 
+#'   while making both larger moves data points closer together.
 #' @param ... Optional arguments to/from other functions
 #' @return Returns a plot object of class \code{ggplot}. 
 #'
@@ -61,6 +67,7 @@
 #'
 #' @example demo/granovagg.ds.R
 #' @export
+#' @references Pruzek, R. M., & Helmreich, J. E. (2009). Enhancing Dependent Sample Analyses with Graphics. Journal of Statistics Education, 17(1), 21.
 #' @references Wickham, H. (2009). Ggplot2: Elegant Graphics for Data Analysis. New York: Springer.
 #' @references Wilkinson, L. (1999). The Grammar of Graphics. Statistics and computing. New York: Springer.
 granovagg.ds <- function(data       = NULL,
@@ -70,21 +77,25 @@ granovagg.ds <- function(data       = NULL,
                          ylab       = NULL,
                          conf.level = 0.95,
                          plot.theme = "theme_granova_ds",
+                         northeast.padding = 0,
+                         southwest.padding = 0,
                          ...
                 ) 
 
 {
   
   GetData <- function(data) {
-    output <- CheckData(data)
-    output <- ReverseXAndY(output)
-    return(output)
+    data <- CheckData(data)
+    data <- ReverseXAndY(data)
+    data <- EnsureDataHasColumnNames(data)
+    data <- EnsureDataIsADataFrame(data)
+    return(data)
   }
   
   CheckData <- function(data) {
     IsDataNull(data)
     IsDataInTwoColumnFormat(data)
-    return(EnsureDataIsADataFrame(data))
+    return(data)
   }
   
   ReverseXAndY <- function(data) {
@@ -122,6 +133,15 @@ granovagg.ds <- function(data       = NULL,
     return(output)
   }
   
+  EnsureDataHasColumnNames <- function(data) {
+    output <- data
+    if (is.null(colnames(data))) {
+      colnames(data) <- c("x", "y")
+    }
+    
+    return(data)
+  }
+  
   GetXs <- function(data) {
     return(data[, 1])
   }
@@ -158,9 +178,9 @@ granovagg.ds <- function(data       = NULL,
     .extrema               <- c(max(.aggregate.data.range), min(.aggregate.data.range))    
     .square.data.range     <- max(.extrema) - min(.extrema)
     .southwest.padding     <- (65/100) * .square.data.range
-    .north.east.padding    <- (15/100) * .square.data.range
+    .northeast.padding     <- (15/100) * .square.data.range
     .lower.graphical.bound <- min(.extrema) - .southwest.padding
-    .upper.graphical.bound <- max(.extrema) + .north.east.padding
+    .upper.graphical.bound <- max(.extrema) + .northeast.padding
     .bounds                <- c(.lower.graphical.bound, .upper.graphical.bound)
     .center                <- mean(.bounds)
     .crossbow.anchor       <- mean(.bounds) + min(.bounds)
@@ -170,7 +190,7 @@ granovagg.ds <- function(data       = NULL,
                 bounds            = .bounds,  
                 shadow.offset     = .shadow.offset,
                 anchor            = .crossbow.anchor,
-                point.size        = I(2),
+                point.size        = I(2.5),
                 mean.line.size    = I(1/2)      
                )
           )
@@ -245,10 +265,73 @@ granovagg.ds <- function(data       = NULL,
                )
           )         
   }
-
+  
+  PrintSummary <- function(dsp) {
+    summary <- GetPrintedSummary(dsp)
+    summary <- RenamePrintedSummaryRows(summary)
+    summary <- round(summary, digits = 3)
+    
+    print(summary)
+  }
+  
+  GetPrintedSummary <- function(dsp) {
+    n <- dim(dsp$data)[1]
+    mean.1 <- mean(dsp$data[, 1])
+    mean.2 <- mean(dsp$data[, 2])
+    mean.d <- mean.1 - mean.2
+    standard.deviation.d <- sd(dsp$data[, 1] - dsp$data[, 2])
+    effect.size <- (mean.d / standard.deviation.d)
+    r.xy <- cor(dsp$data[, 1], dsp$data[, 2])
+    r.x.plus.y.d <- cor((dsp$data[, 1] + dsp$data[, 2]), (dsp$data[, 1] - dsp$data[, 2]))
+    lower.treatment.confidence <- dsp$stats$upper.treatment.effect
+    upper.treatment.confidence <- dsp$stats$lower.treatment.effect
+    t.value <- dsp$t.test$statistic
+    degrees.of.freedom <- dsp$t.test$parameter
+    p.value <- dsp$t.test$p.value
+    
+    return(matrix(c(n, 
+                    mean.1, 
+                    mean.2, 
+                    mean.d, 
+                    standard.deviation.d, 
+                    effect.size, 
+                    r.xy, 
+                    r.x.plus.y.d, 
+                    lower.treatment.confidence, 
+                    upper.treatment.confidence, 
+                    t.value, 
+                    degrees.of.freedom, 
+                    p.value
+                  ), 
+                 ncol = 1
+           )
+    )
+  }
+  
+  RenamePrintedSummaryRows <- function(summary) {
+    dimnames(summary) <- list(
+                           c("n", 
+                             paste(colnames(dsp$data)[1], "mean"), 
+                             paste(colnames(dsp$data)[2], "mean"),
+                             paste("mean(D = ", colnames(dsp$data)[1], " - ", colnames(dsp$data)[2], ")",  sep = ""),
+                             paste("SD(D)"),
+                             paste("Effect Size"),
+                             paste("r(", colnames(dsp$data)[1], ", ", colnames(dsp$data)[2], ")", sep = ""),
+                             paste("r(", colnames(dsp$data)[1], " + ", colnames(dsp$data)[2], ", D)", sep = ""),
+                             paste("Lower ", (100 * conf.level), "% ", "Confidence Interval", sep = ""),
+                             paste("Upper ", (100 * conf.level), "% ", "Confidence Interval", sep = ""),
+                             paste("t (D-bar)"),
+                             paste("df.t"),
+                             paste("p-value (t-statistic)")
+                           ), "Summary Statistics")
+                         
+    return(summary)
+  }
+  
   dsp                <- list(data = GetData(data))
   dsp$effect         <- GetEffect(dsp)
   dsp$stats          <- GetStats(dsp, conf.level)
+  dsp$t.test         <- GetTtest(dsp$data, conf.level)
   dsp$params         <- GetGraphicsParams(dsp)
   dsp$shadows        <- GetShadows(dsp)
   dsp$crossbow       <- GetCrossbow(dsp)
@@ -258,6 +341,7 @@ granovagg.ds <- function(data       = NULL,
   dsp$treatment.line <- GetTreatmentLine(dsp)
   dsp$trails         <- GetTrails(dsp)
   dsp$colors         <- GetColors(dsp)
+  PrintSummary(dsp)
     
   
 
@@ -266,12 +350,13 @@ granovagg.ds <- function(data       = NULL,
 
   
   InitializeGgplot <- function(dsp) {
-    return(ggplot(aes_string(x = names(dsp$data)[1], 
-                             y = names(dsp$data)[2]
-                            ),
-                  data = dsp$data
-                 )
-          )
+    return(
+      ggplot(
+        aes_string(x = dsp$data[1], 
+                   y = dsp$data[2]
+        ), data = dsp$data
+      )
+    )
   }
     
   TreatmentLine <- function(dsp) {
@@ -307,6 +392,18 @@ granovagg.ds <- function(data       = NULL,
   ScaleY <- function(dsp) {
     return(scale_y_continuous(limits = dsp$params$bounds))
   }
+  
+  PadViewingWindow <- function(params) {
+    ne.offset = params$square.data.range * southwest.padding
+    sw.offset = params$square.data.range * northeast.padding
+    padded.window = c(params$bounds[1] - sw.offset, params$bounds[2] + ne.offset)
+    
+    return(
+      coord_cartesian(xlim = padded.window,
+                      ylim = padded.window
+      )
+    )
+  } 
 
   RugPlot <- function(dsp) {
     return(geom_rug_alt(size  = I(1/2),
@@ -372,7 +469,7 @@ granovagg.ds <- function(data       = NULL,
                       data  = dsp$shadow, 
                       size  = dsp$params$point.size,
                       shape = 16,
-                      alpha = I(1/4) 
+                      alpha = I(1/2) 
                      )
           )
   }
@@ -395,7 +492,7 @@ granovagg.ds <- function(data       = NULL,
   ColorScale <- function(dsp) {
     colors <- c(dsp$colors$treatment.line, dsp$colors$CIBand)
   
-    return(scale_color_manual(value = colors, name = ""))
+    return(scale_color_manual(values = colors, name = ""))
   }
 
   XLabel <- function(dsp) {
@@ -427,7 +524,7 @@ granovagg.ds <- function(data       = NULL,
   }
   
   ForceCoordinateAxesToBeEqual <- function() {
-    return(coord_fixed())
+    return(coord_fixed(ratio = 1))
   }
   
           
@@ -444,6 +541,7 @@ granovagg.ds <- function(data       = NULL,
   p <- p + CIBand(dsp)
   p <- p + ColorScale(dsp)
   p <- p + ScaleX(dsp) + ScaleY(dsp)
+  p <- p + PadViewingWindow(dsp$params)
   p <- p + ForceCoordinateAxesToBeEqual()
   p <- p + Title()
   p <- p + XLabel(dsp)
