@@ -1,14 +1,14 @@
 data(arousal)
 #Drug A
-granovagg.1w(arousal[,1:2], h.rng = 1.6, v.rng = 0.5, top.dot = .35)
+granovagg.1w(arousal[,1:2], h.rng = 1.6, v.rng = 0.5)
 
-#########################
+###
 
-library(MASS)
+library(MASS) # Contains the anorexia dataset
 wt.gain <- anorexia[, 3] - anorexia[, 2]
-granovagg.1w(wt.gain, group = anorexia[, 1], size.line = -3)
+granovagg.1w(wt.gain, group = anorexia[, 1])
 
-##########################
+###
 
 data(poison)
 ##Note violation of constant variance across groups in following graphic.
@@ -24,3 +24,9 @@ granovagg.1w(poison$RankRateSurvTime, group = poison$Group,
 ylab = "Ranked and Centered Survival Rates",
 main = "One-way ANOVA display, poison data (ignoring 2-way set-up)", 
 res = TRUE)
+
+###
+
+data(chickwts)
+?chickwts # An explanation of the chickwts dataset
+with(chickwts, granovagg.1w(weight, group = feed)) # Modeling weight as explained by feed type
